package fr.nitorac.aurionweb;

import android.content.Context;
import android.content.SharedPreferences;

import java.io.IOException;
import java.security.GeneralSecurityException;

import fr.nitorac.aurionweb.aurionweb.AurionCred;
import fr.nitorac.aurionweb.security.SecurityManager;

public class StorageManager {

    public final static String MAIN_SHARED_PREF = "main_prefs";
    public static final String SEC_SHARED_PREF = "secstore";

    private static StorageManager instance;

    public StorageManager(){

    }

    public AurionCred getCreds(Context c) throws GeneralSecurityException, IOException {
        SharedPreferences pref = c.getSharedPreferences(StorageManager.SEC_SHARED_PREF, Context.MODE_PRIVATE);
        AurionCred cred = new AurionCred();
        cred.setLogin(pref.getString(AurionCred.LOGIN_KEY, ""));
        String encrypted = pref.getString(AurionCred.PWD_KEY, "");
        if(cred.getLogin().trim().isEmpty() || encrypted.trim().isEmpty()){
            return null;
        }
        cred.setPlainPwd(SecurityManager.getSecurityHelper(c).decrypt(encrypted));
        cred.setRemember(pref.getBoolean(AurionCred.REM_KEY, false));
        return cred;
    }

    public void saveCreds(Context c, AurionCred cred) throws GeneralSecurityException, IOException {
        SharedPreferences pref = c.getSharedPreferences(StorageManager.SEC_SHARED_PREF, Context.MODE_PRIVATE);
        SharedPreferences.Editor edit = pref.edit();
        edit.putString(AurionCred.LOGIN_KEY, cred.getLogin());
        edit.putString(AurionCred.PWD_KEY, SecurityManager.getSecurityHelper(c).encrypt(cred.getPlainPwd()));
        edit.putBoolean(AurionCred.REM_KEY, cred.isRemember());
        edit.apply();
    }

    public static StorageManager getInstance(){
        if(instance == null){
            instance = new StorageManager();
        }

        return instance;
    }
}
